<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>InfoDistancePP</name>
    <message>
        <location filename="../InfoDistancePP.js" line="+59"/>
        <source>First point</source>
        <translation>První bod</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second point</source>
        <translation>Druhý bod</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation>Dokončeno</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Distance:</source>
        <translation>Vzdálenost:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Delta X:</source>
        <translation>Delta X:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta Y:</source>
        <translation>Delta Y:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle:</source>
        <translation>Úhel:</translation>
    </message>
    <message>
        <location filename="../InfoDistancePPInit.js" line="+2"/>
        <source>Distance &amp;Point to Point</source>
        <translation>Vzdálenost mezi &amp;body</translation>
    </message>
</context>
</TS>
